@@ -7,52 +7,52 @@ set.seed(2581)
 
 
 ###################################################
-### code chunk number 2: quantspec.Rnw:549-550
+### code chunk number 2: quantspec.Rnw:551-552
 ###################################################
-library(quantspec)
+library("quantspec")
 
 
 ###################################################
-### code chunk number 3: quantspec.Rnw:556-557 (eval = FALSE)
+### code chunk number 3: quantspec.Rnw:558-559 (eval = FALSE)
 ###################################################
-## help(quantspec)       # alternatively: package?quantspec
+## help("quantspec")
 
 
 ###################################################
-### code chunk number 4: quantspec.Rnw:565-567 (eval = FALSE)
+### code chunk number 4: quantspec.Rnw:568-570 (eval = FALSE)
 ###################################################
-## help(qRegEstimator)
-## help(QRegEstimator)   # alternatively: class?QRegEstimator
+## help("qRegEstimator")
+## help("QRegEstimator")
 
 
 ###################################################
-### code chunk number 5: quantspec.Rnw:576-578
+### code chunk number 5: quantspec.Rnw:579-581
 ###################################################
 Y  <- rnorm(8)
-bn <- qRegEstimator(Y, levels = c(0.25,0.5,0.75))
+bn <- qRegEstimator(Y, levels = c(0.25, 0.5, 0.75))
 
 
 ###################################################
-### code chunk number 6: quantspec.Rnw:585-586
+### code chunk number 6: quantspec.Rnw:588-589
 ###################################################
 bn
 
 
 ###################################################
-### code chunk number 7: quantspec.Rnw:598-600
+### code chunk number 7: quantspec.Rnw:601-603
 ###################################################
 getFrequencies(bn)
 getParallel(bn)
 
 
 ###################################################
-### code chunk number 8: quantspec.Rnw:609-610
+### code chunk number 8: quantspec.Rnw:612-613
 ###################################################
-getValues(bn, levels = c(0.25,0.5))
+getValues(bn, levels = c(0.25, 0.5))
 
 
 ###################################################
-### code chunk number 9: quantspec.Rnw:618-619 (eval = FALSE)
+### code chunk number 9: quantspec.Rnw:621-622 (eval = FALSE)
 ###################################################
 ## help("getValues-FreqRep")
 
@@ -60,41 +60,41 @@ getValues(bn, levels = c(0.25,0.5))
 ###################################################
 ### code chunk number 10: plotbn (eval = FALSE)
 ###################################################
-## dn <- clippedFT(rnorm(32), levels = seq(0.05,0.95,0.05))
-## plot(dn, frequencies = 2*pi*(0:64)/32, levels = c(0.25,0.5))
+## dn <- clippedFT(rnorm(32), levels = seq(0.05, 0.95, 0.05))
+## plot(dn, frequencies = 2 * pi * (0:64) / 32, levels = c(0.25, 0.5))
 
 
 ###################################################
-### code chunk number 11: quantspec.Rnw:639-640
+### code chunk number 11: quantspec.Rnw:642-643
 ###################################################
-dn <- clippedFT(rnorm(32), levels = seq(0.05,0.95,0.05))
-plot(dn, frequencies = 2*pi*(0:64)/32, levels = c(0.25,0.5))
+dn <- clippedFT(rnorm(32), levels = seq(0.05, 0.95, 0.05))
+plot(dn, frequencies = 2 * pi * (0:64) / 32, levels = c(0.25, 0.5))
 
 
 ###################################################
-### code chunk number 12: quantspec.Rnw:676-679 (eval = FALSE)
+### code chunk number 12: quantspec.Rnw:679-682 (eval = FALSE)
 ###################################################
-## demo(sp500)
-## demo(wheatprices)
+## demo("sp500")
+## demo("wheatprices")
 ## demo("qar-simulation")
 
 
 ###################################################
 ### code chunk number 13: plotSP (eval = FALSE)
 ###################################################
-## library(zoo)
+## library("zoo")
 ## plot(sp500,            xlab = "time t", ylab = "", main = "")
 ## acf(coredata(sp500),   xlab = "lag k",  ylab = "", main = "")
 ## acf(coredata(sp500)^2, xlab = "lag k",  ylab = "", main = "")
 
 
 ###################################################
-### code chunk number 14: quantspec.Rnw:726-731
+### code chunk number 14: quantspec.Rnw:729-734
 ###################################################
 def.par <- par(no.readonly = TRUE) # save default, for resetting...
 layout(matrix(c(1,1,2,3), nrow=1))
 par(mar=c(5,2,2,1))
-library(zoo)
+library("zoo")
 plot(sp500,            xlab = "time t", ylab = "", main = "")
 acf(coredata(sp500),   xlab = "lag k",  ylab = "", main = "")
 acf(coredata(sp500)^2, xlab = "lag k",  ylab = "", main = "")
@@ -104,91 +104,91 @@ par(def.par)  #- reset to default
 ###################################################
 ### code chunk number 15: SPquantilePG (eval = FALSE)
 ###################################################
-## CR <- quantilePG(sp500, levels.1 = c(0.05,0.5,0.95),
+## CR <- quantilePG(sp500, levels.1 = c(0.05, 0.5, 0.95),
 ##     type = "clipped", type.boot = "mbb", B = 250, l = 32)
 ## freq <- getFrequencies(CR)
-## plot(CR, levels = c(0.05,0.5,0.95),
+## plot(CR, levels = c(0.05, 0.5, 0.95),
 ##     frequencies = freq[freq > 0 & freq <= pi],
-##     ylab = expression({I[list(n,R)]^{list(tau[1],tau[2])}}(omega)))
+##     ylab = expression({I[list(n, R)]^{list(tau[1], tau[2])}}(omega)))
 
 
 ###################################################
 ### code chunk number 16: SPquantilePG2 (eval = FALSE)
 ###################################################
-## plot(CR, levels = c(0.05,0.5,0.95),
+## plot(CR, levels = c(0.05, 0.5, 0.95),
 ##     frequencies = freq[freq > 0 & freq <= pi/5],
-##     ylab = expression({I[list(n,R)]^{list(tau[1],tau[2])}}(omega)))
+##     ylab = expression({I[list(n, R)]^{list(tau[1], tau[2])}}(omega)))
 
 
 ###################################################
-### code chunk number 17: quantspec.Rnw:807-808 (eval = FALSE)
+### code chunk number 17: quantspec.Rnw:810-811 (eval = FALSE)
 ###################################################
-## help(kernels)
+## help("kernels")
 
 
 ###################################################
 ### code chunk number 18: SPsmoothedPG (eval = FALSE)
 ###################################################
-## sPG <- smoothedPG(CR, weight=kernelWeight(W=W1, bw=0.07))
-## plot(sPG, levels = c(0.05,0.5,0.95), type.scaling = "individual",
+## sPG <- smoothedPG(CR, weight = kernelWeight(W = W1, bw = 0.07))
+## plot(sPG, levels = c(0.05, 0.5, 0.95), type.scaling = "individual",
 ##     frequencies = freq[freq > 0 & freq <= pi], ptw.CIs = 0.1,
-##     ylab = expression(hat(G)[list(n,R)](list(tau[1],tau[2],omega))))
+##     ylab = expression(hat(G)[list(n, R)](list(tau[1], tau[2], omega))))
 
 
 ###################################################
 ### code chunk number 19: SPsmoothedPGboot (eval = FALSE)
 ###################################################
-## plot(sPG, levels = c(0.05,0.5,0.95), type.scaling = "real-imaginary",
+## plot(sPG, levels = c(0.05, 0.5, 0.95), type.scaling = "real-imaginary",
 ##     ptw.CIs = 0.1, type.CIs = "boot.full",
 ##     frequencies = freq[freq > 0 & freq <= pi],
-##     ylab = expression(hat(G)[list(n,R)](list(tau[1],tau[2],omega))))
+##     ylab = expression(hat(G)[list(n, R)](list(tau[1], tau[2], omega))))
 
 
 ###################################################
-### code chunk number 20: quantspec.Rnw:845-846 (eval = FALSE)
+### code chunk number 20: quantspec.Rnw:848-849 (eval = FALSE)
 ###################################################
 ## help("plot-SmoothedPG")
 
 
 ###################################################
-### code chunk number 21: quantspec.Rnw:862-863
+### code chunk number 21: quantspec.Rnw:865-866
 ###################################################
-CR <- quantilePG(sp500, levels.1 = c(0.05,0.5,0.95),
+CR <- quantilePG(sp500, levels.1 = c(0.05, 0.5, 0.95),
     type = "clipped", type.boot = "mbb", B = 250, l = 32)
 freq <- getFrequencies(CR)
-plot(CR, levels = c(0.05,0.5,0.95),
+plot(CR, levels = c(0.05, 0.5, 0.95),
     frequencies = freq[freq > 0 & freq <= pi],
-    ylab = expression({I[list(n,R)]^{list(tau[1],tau[2])}}(omega)))
+    ylab = expression({I[list(n, R)]^{list(tau[1], tau[2])}}(omega)))
 
 
 ###################################################
-### code chunk number 22: quantspec.Rnw:872-873
+### code chunk number 22: quantspec.Rnw:875-876
 ###################################################
-plot(CR, levels = c(0.05,0.5,0.95),
+plot(CR, levels = c(0.05, 0.5, 0.95),
     frequencies = freq[freq > 0 & freq <= pi/5],
-    ylab = expression({I[list(n,R)]^{list(tau[1],tau[2])}}(omega)))
+    ylab = expression({I[list(n, R)]^{list(tau[1], tau[2])}}(omega)))
 
 
 ###################################################
-### code chunk number 23: quantspec.Rnw:886-887
+### code chunk number 23: quantspec.Rnw:889-890
 ###################################################
-sPG <- smoothedPG(CR, weight=kernelWeight(W=W1, bw=0.07))
-plot(sPG, levels = c(0.05,0.5,0.95), type.scaling = "individual",
+sPG <- smoothedPG(CR, weight = kernelWeight(W = W1, bw = 0.07))
+plot(sPG, levels = c(0.05, 0.5, 0.95), type.scaling = "individual",
     frequencies = freq[freq > 0 & freq <= pi], ptw.CIs = 0.1,
-    ylab = expression(hat(G)[list(n,R)](list(tau[1],tau[2],omega))))
+    ylab = expression(hat(G)[list(n, R)](list(tau[1], tau[2], omega))))
 
 
 ###################################################
-### code chunk number 24: quantspec.Rnw:897-898
+### code chunk number 24: quantspec.Rnw:900-901
 ###################################################
-plot(sPG, levels = c(0.05,0.5,0.95), type.scaling = "real-imaginary",
+plot(sPG, levels = c(0.05, 0.5, 0.95), type.scaling = "real-imaginary",
     ptw.CIs = 0.1, type.CIs = "boot.full",
     frequencies = freq[freq > 0 & freq <= pi],
-    ylab = expression(hat(G)[list(n,R)](list(tau[1],tau[2],omega))))
+    ylab = expression(hat(G)[list(n, R)](list(tau[1], tau[2], omega))))
 
 
 ###################################################
-### code chunk number 25: quantspec.Rnw:937-938 (eval = FALSE)
+### code chunk number 25: quantspec.Rnw:940-941 (eval = FALSE)
 ###################################################
 ## help("ts-models")
 
@@ -196,9 +196,9 @@ plot(sPG, levels = c(0.05,0.5,0.95), type.scaling = "real-imaginary",
 ###################################################
 ### code chunk number 26: csdQAR (eval = FALSE)
 ###################################################
-## csd <- quantileSD(N=2^9, seed.init = 2581, type = "copula",
-##         ts = ts1, levels.1 = c(0.25, 0.5, 0.75), R = 100, quiet=TRUE)
-## plot(csd, ylab = expression(f[list(q[tau[1]],q[tau[2]])](omega)))
+## csd <- quantileSD(N = 2^9, seed.init = 2581, type = "copula",
+##         ts = ts1, levels.1 = c(0.25, 0.5, 0.75), R = 100, quiet = TRUE)
+## plot(csd, ylab = expression(f[list(q[tau[1]], q[tau[2]])](omega)))
 
 
 ###################################################
@@ -210,7 +210,7 @@ plot(sPG, levels = c(0.05,0.5,0.95), type.scaling = "real-imaginary",
 
 
 ###################################################
-### code chunk number 28: quantspec.Rnw:972-973 (eval = FALSE)
+### code chunk number 28: quantspec.Rnw:975-976 (eval = FALSE)
 ###################################################
 ## help("increasePrecision-QuantileSD")
 
@@ -219,82 +219,82 @@ plot(sPG, levels = c(0.05,0.5,0.95), type.scaling = "real-imaginary",
 ### code chunk number 29: csdQARhighprecPlot (eval = FALSE)
 ###################################################
 ## load("csd-qar1.rdata")
-## plot(csd, frequencies = 2*pi*(1:2^8)/2^9,
-##     ylab = expression(f[list(q[tau[1]],q[tau[2]])](omega)))
+## plot(csd, frequencies = 2 * pi * (1:2^8) / 2^9,
+##     ylab = expression(f[list(q[tau[1]], q[tau[2]])](omega)))
 
 
 ###################################################
-### code chunk number 30: quantspec.Rnw:994-999 (eval = FALSE)
+### code chunk number 30: quantspec.Rnw:997-1002 (eval = FALSE)
 ###################################################
-## sCR <- smoothedPG(ts1(512), levels.1 = c(0.25,0.5,0.75),
-##     weight=kernelWeight(W=W1, bw=0.1))
+## sCR <- smoothedPG(ts1(512), levels.1 = c(0.25, 0.5, 0.75),
+##     weight = kernelWeight(W = W1, bw = 0.1))
 ## plot(sCR, qsd = csd,
-##     ylab = bquote(paste(hat(G)[list(n,R)](list(tau[1],tau[2],omega)),
-##     " and ", f[list(q[tau[1]],q[tau[2]])](omega))))
+##     ylab = bquote(paste(hat(G)[list(n, R)](list(tau[1], tau[2], omega)),
+##     " and ", f[list(q[tau[1]], q[tau[2]])](omega))))
 
 
 ###################################################
-### code chunk number 31: quantspec.Rnw:1014-1028 (eval = FALSE)
+### code chunk number 31: quantspec.Rnw:1017-1031 (eval = FALSE)
 ###################################################
 ## set.seed(2581)
 ## ts <- ts1
 ## N <- 128
 ## R <- 5000
 ## 
-## freq <- 2*pi*(1:16)/32
+## freq <- 2  * pi * (1:16) / 32
 ## levels <- c(0.25, 0.5, 0.75)
 ## 
 ## J <- length(freq)
 ## K <- length(levels)
 ## 
-## sims  <- array(0, dim=c(4,R,J,K,K))
+## sims  <- array(0, dim=c(4, R, J, K, K))
 ## 
-## weight <- kernelWeight(W=W1, bw=0.3)
+## weight <- kernelWeight(W = W1, bw = 0.3)
 
 
 ###################################################
-### code chunk number 32: quantspec.Rnw:1047-1048
+### code chunk number 32: quantspec.Rnw:1050-1051
 ###################################################
-csd <- quantileSD(N=2^9, seed.init = 2581, type = "copula",
-        ts = ts1, levels.1 = c(0.25, 0.5, 0.75), R = 100, quiet=TRUE)
-plot(csd, ylab = expression(f[list(q[tau[1]],q[tau[2]])](omega)))
+csd <- quantileSD(N = 2^9, seed.init = 2581, type = "copula",
+        ts = ts1, levels.1 = c(0.25, 0.5, 0.75), R = 100, quiet = TRUE)
+plot(csd, ylab = expression(f[list(q[tau[1]], q[tau[2]])](omega)))
 
 
 ###################################################
-### code chunk number 33: quantspec.Rnw:1073-1079
+### code chunk number 33: quantspec.Rnw:1076-1082
 ###################################################
 set.seed(020581)
-sCR <- smoothedPG(ts1(512), levels.1 = c(0.25,0.5,0.75),
-        weight=kernelWeight(W=W1, bw=0.1))
+sCR <- smoothedPG(ts1(512), levels.1 = c(0.25, 0.5, 0.75),
+        weight = kernelWeight(W = W1, bw = 0.1))
 plot(sCR, qsd = csd,
-    ylab = bquote(paste(hat(G)[list(n,R)](list(tau[1],tau[2],omega)),
-    " and ", f[list(q[tau[1]],q[tau[2]])](omega))))
+    ylab = bquote(paste(hat(G)[list(n, R)](list(tau[1], tau[2], omega)),
+    " and ", f[list(q[tau[1]], q[tau[2]])](omega))))
 
 
 ###################################################
-### code chunk number 34: quantspec.Rnw:1093-1106 (eval = FALSE)
+### code chunk number 34: quantspec.Rnw:1096-1109 (eval = FALSE)
 ###################################################
 ## for (i in 1:R) {
 ##   Y <- ts(N)
 ## 
-##   CR  <- quantilePG(Y, levels.1=levels, type="clipped")
-##   LP  <- quantilePG(Y, levels.1=levels, type="qr")
-##   sCR <- smoothedPG(CR, weight=weight)
-##   sLP <- smoothedPG(LP, weight=weight)
+##   CR  <- quantilePG(Y, levels.1=levels, type = "clipped")
+##   LP  <- quantilePG(Y, levels.1=levels, type = "qr")
+##   sCR <- smoothedPG(CR, weight = weight)
+##   sLP <- smoothedPG(LP, weight = weight)
 ## 
-##   sims[1,i,,,] <- getValues(CR, frequencies=freq)[,,,1]
-##   sims[2,i,,,] <- getValues(LP, frequencies=freq)[,,,1]
-##   sims[3,i,,,] <- getValues(sCR, frequencies=freq)[,,,1]
-##   sims[4,i,,,] <- getValues(sLP, frequencies=freq)[,,,1]
+##   sims[1, i, , , ] <- getValues(CR,  frequencies=freq)[, , , 1]
+##   sims[2, i, , , ] <- getValues(LP,  frequencies=freq)[, , , 1]
+##   sims[3, i, , , ] <- getValues(sCR, frequencies=freq)[, , , 1]
+##   sims[4, i, , , ] <- getValues(sLP, frequencies=freq)[, , , 1]
 ## }
 
 
 ###################################################
-### code chunk number 35: quantspec.Rnw:1118-1122 (eval = FALSE)
+### code chunk number 35: quantspec.Rnw:1121-1125 (eval = FALSE)
 ###################################################
-## trueV <- getValues(csd, frequencies=freq)
-## SqDev <- array(apply(sims, c(1,2),
-##         function(x) {abs(x-trueV)^2}), dim=c(J,K,K,4,R))
-## rimse <- sqrt(apply(SqDev, c(2,3,4), mean))
+## trueV <- getValues(csd, frequencies = freq)
+## SqDev <- array(apply(sims, c(1, 2),
+##         function(x) {abs(x - trueV)^2}), dim=c(J, K, K, 4, R))
+## rimse <- sqrt(apply(SqDev, c(2, 3, 4), mean))
 
 
